/* Nilo - A Network boot loader.

   Copyright (C) 1999 Free Software Foundation, Inc.

This file is part of Nilo.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */

/* This is generated by running configure */
#include "niloconfig.h"

/* Define the basic data types */
#include <sys/types.h>

/* Define the PXE types */
#include "pxe_types.h"

/* Define the tracing macros */
#include "trace.h"

/* Define the TFTP data structures */
#include "tftp.h"

/* Define the BOOTP data structures */
#include "bootp.h"

/* dump the contents of a BOOTP packet */
void
dump_bootp_packet(bootp_t *bpr)
{
    unsigned char *p;
    int i;
    
    NILO_TRACE_FUNCTION;

    NILO_TRACE_MSG ("bootp.bp_opcode: 0x%x\n", bpr->bp_opcode);
    NILO_TRACE_MSG ("bootp.bp_htype: 0x%x\n", bpr->bp_htype);
    NILO_TRACE_MSG ("bootp.bp_hlen: 0x%x\n", bpr->bp_hlen);
    NILO_TRACE_MSG ("bootp.bp_hops: 0x%x\n", bpr->bp_hops);
    NILO_TRACE_MSG ("bootp.xid: 0x%04x\n", bpr->bp_xid);
    NILO_TRACE_MSG ("bootp.bp_secs: 0x%02x\n", bpr->bp_secs);
    NILO_TRACE_MSG ("bootp.bp_flags: 0x%02x\n", bpr->bp_flags);

    NILO_TRACE_MSG ("bootp.bp_ciaddr: 0x%04x, (%s)\n", bpr->bp_ciaddr.num,
                    _inet_ntoa(bpr->bp_ciaddr.num));
    NILO_TRACE_MSG ("bootp.bp_yiaddr: 0x%04x, (%s)\n", bpr->bp_yiaddr.num,
                    _inet_ntoa(bpr->bp_yiaddr.num));
    NILO_TRACE_MSG ("bootp.bp_siaddr: 0x%04x, (%s)\n", bpr->bp_siaddr.num,
                    _inet_ntoa(bpr->bp_siaddr.num));
    NILO_TRACE_MSG ("bootp.bp_giaddr: 0x%04x, (%s)\n", bpr->bp_giaddr.num,
                    _inet_ntoa(bpr->bp_giaddr.num));

    NILO_TRACE_MSG ("bootp.bp_chaddr: %s\n", hexify_buffer (bpr->bp_chaddr, BP_CHADDR_LEN/2));

    NILO_TRACE_MSG ("bootp.bp_sname: %s\n", (*bpr->bp_sname) ? (char *)bpr->bp_chaddr: "none yet");
    NILO_TRACE_MSG ("bootp.bp_file: %s\n", (*bpr->bp_file) ? bpr->bp_file: "none yet");

#ifdef NILO_PXE_COMP
    union {
        u_int8_t d[BP_VEND_LEN];        /* vendor-specific area */
        struct {
            u_int8_t  magic[4];         /* magic number */
            u_int32_t flags;            /* flags/opcodes etc */
            u_int8_t  pad[56];          /* padding chars */
        } v;
    } bp_options;
#else
    NILO_TRACE_MSG ("bootp.bp_vend:");
    for (p = bpr->bp_options; p < &bpr->bp_options[200] && *p != TAG_END; ++p)
        NILO_TRACE_PRINTF (" 0x%02x", *p);
    NILO_TRACE_PRINTF ("\n");
#endif
    NILO_TRACE_FUNCTION_RETURN;
}

/* dump the contents of a TFTP packet */
void
dump_tftp_packet(tftp_t *tpr)
{
    unsigned char *p;
    int i;
    
    NILO_TRACE_FUNCTION;

    switch (tpr->opcode)
    {
    case TFTP_RRQ:
        NILO_TRACE_MSG ("tftp.opcode: RRQ (0x%02x)\n", tpr->opcode);
        break;
    case TFTP_ACK:
        NILO_TRACE_MSG ("tftp.opcode: ACK (0x%02x)\n", tpr->opcode);
        break;
    default:
        NILO_TRACE_MSG ("tftp.opcode: 0x%02x\n", tpr->opcode);
    }

    NILO_TRACE_MSG ("tftp.u.data: %s lots more...\n", hexify_buffer(tpr->u.rrq, 30));

    NILO_TRACE_FUNCTION_RETURN;
}

