/* Nilo - A Network boot loader.

   Copyright (C) 1999 Free Software Foundation, Inc.

This file is part of Nilo.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */

#ifndef __NILO_H__
#define __NILO_H__

/* This is the include generated by configuring */
#include "niloconfig.h"

/* Define the PXE types */
#include "pxe_types.h"

/* Define the bootp data structures */
#include "bootp.h"

/* Define the TFTP data structures */
#include "tftp.h"

/*
 *	These should be used where sizes are important, e.g. protocol
 *	packets.
 */

/* Stolen from netboot */
#define ETH_ALEN        6

struct device;
struct bootp_t;
struct tftp_t;

/* The magic number is at the end because this goes at the top of 640k */
struct protocol_table
{
	u_int8_t macaddr[ETH_ALEN];
	struct device *dev;
        bootp_t *bpr;		/* pointer to bootp reply */
	void (*bootp_handler)(u_int32_t xid,
                              void (*callback)(int32_t, bootp_t *));
	void (*tftp_handler)(u_int32_t, int16_t opcode,
                             const char *filename, int32_t blockno,
                             void (*callback)(int, tftp_t *));
	int32_t (*wait_for_work)(void);
	u_int32_t version;
	u_int32_t magic;
};

extern void init_system(void);
extern struct protocol_table *init_protocol_code(void);
extern int32_t init_hardware(struct protocol_table *);
extern u_int32_t getxid(void);
extern void store(char *d, char *s, int n);

#endif /* __NILO_H__ */
