/* 
   Copyright (C) 1999 Free Software Foundation, Inc.

This file is part of Nilo.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */

/* This is generated by running configure */
#include "niloconfig.h"

/* Define the basic data types */
#include <sys/types.h>

/* Define the PXE types */
#include "pxe_types.h"

/* Define the tracing macros */
#include "trace.h"

/* Define the TFTP data structures */
#include "pxe_preboot.h"

/* Define the bootp data structures */
#include "bootp.h"

/* pxenv_start_unload_stack() - unload all the boot code and data from
 *      memory. The UNDI driver must be shut down first. The boot code 
 *      data and stack fields in the global pxe structure must be filled
 *      with zeros, and the checksum updated.
 *
 * parameters:
 *     none
 * returns:
 *     stackptr.status - The exit status of this function. This is set
 *                       to one of the PXENV_STATUS_xxx constants.
 */
pxenv_ret_code_t
pxenv_unload_stack (pxenv_unload_stack_t stackptr)
{
    NILO_TRACE_FUNCTION;

    NILO_TRACE_FUNCTION_RETURN;
    return (PXENV_EXIT_SUCCESS);
}

/* pxenv_get_cached_info() - gets the cached info. This returns one of
 *      three data items.
 *      - the client's DHCPDISCOVER packet.
 *      - the boot server's DHCPACK packet.
 *      - the boot server's Discover Reply packet.
 *
 * parameters:
 *     none
 * returns:
 *     cinfo_ptr.status - The exit status of this function. This is set
 *                        to one of the PXENV_STATUS_xxx constants.
 *     cinfo_ptr.pkt_type - the type of packet in the cache.
 *     cinfo_ptr.buffer_size - the size of the receive buffer in bytes. 
 *     cinfo_ptr.buffer - the buffer address in offset:segment format.
 */
pxenv_ret_code_t
pxenv_get_cached_info (pxenv_get_cached_info_t cinfo_ptr)
{
    NILO_TRACE_FUNCTION;

    NILO_TRACE_FUNCTION_RETURN;
    return (PXENV_EXIT_SUCCESS);
}

/* pxenv_restart_tftp() - starts the TFTP connection with the boot server,
 *      and starts download the boot image over the network. As a note, this
 *      function never returns if the TFTP session is started. It also
 *      requires that the network be functioning for this so succeed.
 *
 * parameters:
 *     session.ilename - a NULL terminated string represnting the boot
 *             file name.
 *     session.buffersize - the size of the receive buffer in bytes. 
 *     session.buffer - the buffer address in offset:segment format.
 *     session.server_ip - the IP address of the TFTP server in Big Endian
 *                 format.
 *     session.gw_ip - the IP address of gateway in Big Endian
 *             format.
 *     session.mcast_ip - the multicast IP address in Big Endian format.
 *     session.tftp_clnt_port - the port the client listens to for a multicast.
 *     tsession.ftp_srv_port - the port the server listens to for a multicast.
 *     session.tftp_open_timeout - the timeout value in seconds used for
 *                         receiving data. If zero, the default of
 *			   TFTP timeout is used.
 *     session.tftp_reopen_delay - the maximum wait delay time in seconds
 *                         between ACK of a fast packet and a new
 *                         TFTP open.
 * returns:
 *     session.status - the exit status of this function. This is set to one
 *	                of the PXENV_STATUS_xxx constants.
 *     session.packetnum - the packet sequence number.
 *     session.buffersize - the size of the packet received in the buffer.
 */
pxenv_ret_code_t
pxenv_restart_tftp (pxenv_restart_tftp_t session)
{
    NILO_TRACE_FUNCTION;

    NILO_TRACE_FUNCTION_RETURN;
    return (PXENV_EXIT_SUCCESS);
}

/* pxenv_start_undi() - passes the BIOS parameter registers to the
 *      driver. It is the responsibility of the driver to save this
 *      information if it expects to talk to the hardware. This is also
 *      required to hook the 0x1a service function.
 *
 * parameters:
 *   These must contain the same data that was passed to the option
 *   ROM by the system BIOS.
 *     startundi.ax - this is the value of the AX register.
 *     startundi.bx - this is the value of the BX register.
 *     startundi.dx - this is the value of the DX register.
 *     startundi.di - this is the value of the DI register.
 * returns:
 *     startundi.status - the exit status of this function. This is set
 *                        to one of the PXENV_STATUS_xxx constants.
 */
pxenv_ret_code_t
pxenv_start_undi (pxenv_start_undi_t startundi)
{
    NILO_TRACE_FUNCTION;

    NILO_TRACE_FUNCTION_RETURN;
    return (PXENV_EXIT_SUCCESS);
}

/* pxenv_stop_undi() - unhooks the 0x1a service function. Must only be
 *      called once at the end of a boot ROM.
 *
 * parameters:
 *     none
 * returns:
 *     stopundi.status - the exit status of this function. This is set
 *                       to one of the PXENV_STATUS_xxx constants.
 */
pxenv_ret_code_t
pxenv_stop_undi (pxenv_stop_undi_t stopundi)
{
    NILO_TRACE_FUNCTION;

    NILO_TRACE_FUNCTION_RETURN;
    return (PXENV_EXIT_SUCCESS);
}

/* pxenv_start_base() - starts the boot connection. This connection
 *      must support the driver's creation of an IP stack and suficient
 *      to start DHCP.
 *
 * parameters:
 *     none
 * returns:
 *     startbase.status - the exit status of this function. This is set
 *                        to one of the PXENV_STATUS_xxx constants.
 */
pxenv_ret_code_t
pxenv_start_base (pxenv_start_base_t startbase)
{
    NILO_TRACE_FUNCTION;

    NILO_TRACE_FUNCTION_RETURN;
    return (PXENV_EXIT_SUCCESS);
}

/* pxenv_stop_base() - stops the boot connection. This requires that the
 *      connection already has been started.
 *
 * parameters:
 *     none
 * returns:
 *     stopbase.status - the exit status of this function. This is set
 *                       to one of the PXENV_STATUS_xxx constants.
 */
pxenv_ret_code_t
pxenv_stop_base (pxenv_stop_base_t stopbase)
{
    NILO_TRACE_FUNCTION;

    NILO_TRACE_FUNCTION_RETURN;
    return (PXENV_EXIT_SUCCESS);
}



