/* 
   Copyright (C) 1999 Free Software Foundation, Inc.

This file is part of Nilo.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */

/* This is generated by running configure */
#include "niloconfig.h"

/* Define the basic data types */
#include <sys/types.h>

/* Define the PXE types */
#include "pxe_types.h"

/* Define the tracing macros */
#include "trace.h"

/* Define the TFTP data structures */
#include "pxe_tftp.h"

/* pxenv_tftp_open() - open the TFTP connection so we can read and write.
 * 
 * parameters:
 *     tftpopen.server_ip - the IP address of the TFTP server
 *                                 in Big Endian Format.
 *     tftpopen.gw_ip - The IP address of gateway in Big Endian
 *                            format.
 *     tftpopen.filename - a NULL terminated string
 *                                  representing the boot file name.
 *     tftpopen.tftpport - the port the TFTP server is
 *                            listening on. This must be in Big Endian
 *                            format.
 *     tftpopen.packetsize - the requested size of the TFTP
 *                            packets. This must be over 512 bytes.
 * returns:
 *     udpwrite.status - the exit status of this function. This is set to
 *                       one of the PXENV_STATUS_xxx constants.
 *     tftpopen.packetsize - the negotiated size of the TFTP packets. Must
 *                       be at least 512 bytes.
 */
pxenv_ret_code_t
pxenv_tftp_open (pxenv_tftp_open_t tftpopen)
{
    NILO_TRACE_FUNCTION;

    NILO_TRACE_FUNCTION_RETURN;
    return (PXENV_EXIT_SUCCESS);
}

/* pxenv_tftp_close() - close the open TFTP connection.
 *
 * parameters:
 *     none
 * returns:
 *     tftpclose.status - The exit status of this function. This is set
 *                        to one of the PXENV_STATUS_xxx constants.
 */
pxenv_ret_code_t
pxenv_tftp_close (pxenv_tftp_close_t tftpclose)
{
    NILO_TRACE_FUNCTION;

    NILO_TRACE_FUNCTION_RETURN;
    return (PXENV_EXIT_SUCCESS);
}

/* pxenv_tftp_read() - read one packet from an open TFTP connection.
 *
 * parameters:
 *     tftpread.filename - a NULL terminated string represnting the boot
 *             file name.
 *     tftpread.buffersize - the size of the receive buffer in bytes. 
 *     tftpread.buffer - the buffer address in offset:segment format.
 *     tftpread.server_ip - the IP address of the TFTP server in Big Endian
 *                 format.
 *     tftpread.gw_ip - the IP address of gateway in Big Endian
 *             format.
 *     tftpread.mcast_ip - the multicast IP address in Big Endian format.
 *     tftpread.tftp_clnt_port - the port the client listens to for a
 *                               multicast.
 *     tftpread.tftp_srv_port - the port the server listens to for a
 *                              multicast.
 *     tftpread.tftp_open_timeout - the timeout value in seconds used for
 *                         receiving data. If zero, the default of
 *                         TFTP timeout is used.
 *     tftpread.tftp_reopen_delay - the maximum wait delay time in seconds
 *                         between ACK of a fast packet and a new
 *                         TFTP open.
 * returns:
 *     tftpread.status - The exit status of this function. This is set to
 *                       one of the PXENV_STATUS_xxx constants.
 *     tftpread.packetnum - the packet sequence number.
 *     tftpread.buffersize - the size of the packet received in
 *               the buffer.
 */
pxenv_ret_code_t
pxenv_tftp_read (pxenv_tftp_read_t tftpread)
{
    NILO_TRACE_FUNCTION;

    NILO_TRACE_FUNCTION_RETURN;
    return (PXENV_EXIT_SUCCESS);
}

/* pxenv_tftp_read_file() - open the TFTP connection, load the entire
 *      file, and close the connection.
 *
 * parameters:
 *     tftpfile.filename - a NULL terminated string represnting the boot
 *             file name.
 *     tftpfile.buffersize - the size of the receive buffer in bytes. 
 *     tftpfile.buffer - the buffer address in offset:segment format.
 *     tftpfile.server_ip - the IP address of the TFTP server in Big Endian
 *                 format.
 *     tftpfile.gw_ip - the IP address of gateway in Big Endian
 *             format.
 *     tftpfile.mcast_ip - the multicast IP address in Big Endian format.
 *     tftpfile.tftp_clnt_port - the port the client listens to for a
 *                               multicast.
 *     tftpfile.tftp_srv_port - the port the server listens to for a
 *                              multicast.
 *     tftpfile.tftp_open_timeout - the timeout value in seconds used for
 *                         receiving data. If zero, the default of
 *                         TFTP timeout is used.
 *     tftpfile.tftp_reopen_delay - the maximum wait delay time in seconds
 *                         between ACK of a fast packet and a new
 *                         TFTP open.
 * returns:
 *     tftpfile.status - The exit status of this function. This is set to one
 *              of the PXENV_STATUS_xxx constants.
 *     tftpfile.packetnum - the packet sequence number.
 *     tftpfile.buffersize - the size of the packet received in the buffer.
 */
pxenv_ret_code_t
pxenv_tftp_read_file (pxenv_tftp_read_file_t tftpfile)
{
    NILO_TRACE_FUNCTION;

    NILO_TRACE_FUNCTION_RETURN;
    return (PXENV_EXIT_SUCCESS);
}

/* pxenv_tftp_get_fsize() - get the size of the file to download. This must
 *      not be called when there is an open connection.
 *
 * parameters:
 *     tftpfsize.server_ip - the IP address of the TFTP server in Big Endian
 *                 format.
 *     tftpfsize.gw_ip - The IP address of gateway in Big Endian
 *             format.
 *     tftpfsize.filename - a NULL terminated string represnting the boot
 *             file name.
 *     tftpfsize.tftpport - the port the TFTP server is listening on. This
 *                          must be in Big Endian format.
 * returns:
 *     tftpfsize.status - The exit status of this function. This is set
 *                        to one of the PXENV_STATUS_xxx constants.
 *     tftpfsize.filesize - the size of the boot file in bytes.
 */
pxenv_ret_code_t
pxenv_tftp_get_fsize (pxenv_tftp_get_fsize_t tftpfsize)
{
    NILO_TRACE_FUNCTION;

    NILO_TRACE_FUNCTION_RETURN;
    return (PXENV_EXIT_SUCCESS);
}



