/* Nilo - A Network boot loader.

   Copyright (C) 1999 Free Software Foundation, Inc.

This file is part of Nilo.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */

/* This is generated by running configure */
#include "niloconfig.h"

/* Define the basic data types */
#include <sys/types.h>

/* Define the PXE types */
#include "pxe_types.h"

/* Define the tracing macros */
#include "trace.h"

/* Define the TFTP data structures */
#include "tftp.h"

/* Define the debug functions that can print the data structures. */
#include "dump.h"

#include <stdarg.h>
#include <sys/types.h>
#include <arpa/inet.h>
#include "tftp.h"
#include "vsprintf.h"

int blocksize = 512;

int
fill_tftp_request(tftp_t *tftp_pkt, u_int16_t opcode,
                  const char *filename, int32_t blockno)
{
    NILO_TRACE_FUNCTION;

    tftp_pkt->opcode = htons(opcode);
    if (filename[0] == '\0')
        filename = TFTP_DEFAULT_FILENAME;

#ifdef NILO_USE_TRACING
    dump_tftp_packet (tftp_pkt);
#endif /* NILO_USE_TRACE */

    switch (opcode)
    {
    case TFTP_RRQ:
        return (sizeof(short) + sprintf(tftp_pkt->u.rrq, "%s%coctet%c"
#ifdef	NILO_USE_LARGETFTP
                                        "blksize%c%d"
#endif
                                        , filename, 0, 0
#ifdef	NILO_USE_LARGETFTP
                                        , 0, TFTP_MAX_PACKET
#endif
            ));
        break;
    case TFTP_ACK:
        tftp_pkt->u.ack.block = htons(blockno);
        return (sizeof(short) * 2);
        break;
    default:
        NILO_TRACE_MSG ("Don't know how to fill with packet type %d\n", opcode);
        break;
    }

    NILO_TRACE_FUNCTION_RETURN;
    return (0);
}




